-- This module provides a semi-decidable equality type class to overload
-- the symbol _=m?_.

open import Lib.Equality as Eq
open import Lib.Maybe
open import Lib.Proposition

module Lib.MaybeEq where

-- ----------------------------------------------------------------------
-- Type class for MaybeEq.

-- The MaybeEq type class has an operation _=m?_. 
record MaybeEq (A : Set) : Set where
  infixl 4 _=m?_
  field
    _=m?_ : (x y : A) -> Maybe (x == y)

-- A special way to open a module to make the record fields available
-- as functions taking instance arguments.
open MaybeEq {{...}} public

open import Lib.Nat

infixl 4 _=N?_
_=N?_ : ∀ (x y : Nat) -> Maybe (x == y) 
zero =N? zero = Just refl
zero =N? succ y = Nothing
succ x =N? zero = Nothing
succ x =N? succ y with x =N? y
... | Just x₁ = Just (context succ x₁)
... | Nothing = Nothing

instance 
  MaybeEq-Nat : MaybeEq Nat
  MaybeEq-Nat ._=m?_ = _=N?_ 

-- MaybeEq can be lifted to List and Word.
open import Lib.List

infixl 4 _=L?_
_=L?_ : ∀ {A} -> {{MaybeEq A}} -> (xs ys : List A) -> Maybe (xs == ys) 
nil =L? nil = Just refl
nil =L? x :: ys = Nothing
x :: xs =L? nil = Nothing
x :: xs =L? x₁ :: ys with x =m? x₁ | xs =L? ys
(x :: xs =L? x₁ :: ys) | Just x₃ | Just x₂ = Just (Eq.cong _::_ x₃ x₂)
(x :: xs =L? x₁ :: ys) | Nothing | Just x₂ = Nothing
x :: xs =L? x₁ :: ys | h | Nothing = Nothing

instance 
  MaybeEq-List : ∀ {A} -> {{MaybeEq A}} -> MaybeEq (List A)
  MaybeEq-List ._=m?_ = _=L?_ 

infixl 4 _=∪?_
_=∪?_ : ∀ {A B} -> {{MaybeEq A}} -> {{MaybeEq B}} -> (x y : A ∪ B) -> Maybe (x == y) 
⌜ x =∪? ⌜ x₁ with x =m? x₁
... | Just refl = Just refl
... | Nothing = Nothing
⌜ x =∪? x₁ ⌝ = Nothing
x ⌝ =∪? ⌜ x₁ = Nothing
x ⌝ =∪? x₁ ⌝ with x =m? x₁
... | Just refl = Just refl
... | Nothing = Nothing

instance 
  MaybeEq-∪ : ∀ {A B} -> {{MaybeEq A}} -> {{MaybeEq B}} -> MaybeEq (A ∪ B)
  MaybeEq-∪ ._=m?_ = _=∪?_
